@@ -1,5 +1,5 @@
 """
-Fabric checks and assertions for RHEL-flavored yum installations
+Fabfile functions for ensuring the state of yum-based Linux Distro packages
 """
 
 import cuisine 
@@ -12,8 +12,13 @@ def grouppackage_installed(groupname):
     """
     Ensure that the group package named `groupname` is installed.
 
+    :param groupname: *required* str; the group package name
+
     If the groupname is not installed, then it will be installed
     using sudo('yum -y groupinstall ...')
+
+    For more information on the available yum group packages, 
+    issue a ``yum grouplist`` from your RHEL/CentOS flavored OS.
     """
     grp_installed = run('yum grouplist installed "%s" | grep -i installed && echo OK; true' % groupname).endswith('OK')
     if not grp_installed:
@@ -25,6 +30,8 @@ def package_installed(package):
     """
     Ensure that a package named `package` is installed.
 
+    :param package: *required* str; the name of the package
+
     Wraps cuisine.package_ensure() + select_package(option='yum')
     """
     cuisine.select_package(option='yum')
